import heyy
from .dbf_utils import (
    dbf2objs,
    str2objs,
    read_fields,
    compare_fields,
    split_multiline,
)

pt = heyy.pathtool
dbf2objs = dbf2objs
str2objs = str2objs
read_fields = read_fields
compare_fields = compare_fields
split_multiline = split_multiline
